PyXMake Developer Guide: PyXMake.Plugin.__poetry.ApplicationPlugin.Command Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Static Public Attributes | List of all members
PyXMake.Plugin.__poetry.ApplicationPlugin.Command Class Reference
Inheritance diagram for PyXMake.Plugin.__poetry.ApplicationPlugin.Command:

## Public Member Functions
| handle (self)
| factory (cls)

## Static Public Attributes
str | name = "housekeeping"
list | supported = ["housekeeping", "release"]

## Detailed Description

    Poetry application command interface

Definition at line 141 of file __poetry.py.

## Member Function Documentation

## ◆ factory()

PyXMake.Plugin.__poetry.ApplicationPlugin.Command.factory | ( |  | cls | ) |

Definition at line 151 of file __poetry.py.

## ◆ handle()

PyXMake.Plugin.__poetry.ApplicationPlugin.Command.handle | ( |  | self | ) |

Definition at line 149 of file __poetry.py.

## Member Data Documentation

## ◆ name

str PyXMake.Plugin.__poetry.ApplicationPlugin.Command.name = "housekeeping"
| static

Definition at line 146 of file __poetry.py.

## ◆ supported

list PyXMake.Plugin.__poetry.ApplicationPlugin.Command.supported = ["housekeeping", "release"]
| static

Definition at line 148 of file __poetry.py.

The documentation for this class was generated from the following file:

- src/PyXMake/Plugin/__poetry.py